@@ -31,6 +31,7 @@ from .compare_utils import get_closest_match_from_list
 from .path_utils import makeAllDirs
 from .list_utils import make_list
 from typing import List, Union, Dict, Any
+from .class_utils import alias
 
 logging.basicConfig(level=logging.DEBUG, format='%(asctime)s - %(levelname)s - %(message)s')
 logger = logging.getLogger(__name__)
@@ -89,6 +90,22 @@ def get_error_msg(error_msg, default_error_msg):
 
 
 
+def safe_write_to_json(file_path:str=None, data:(dict or list or str)=None,*args, ensure_ascii=False, indent=4, error=False, error_msg=None, **kwargs):
+    params = check_read_write_params(file_path=file_path,contents=data,*args, **kwargs)
+    if params:
+        temp_file_path = f"{params[0]}.temp"
+        var_data = {"file_path": temp_file_path, "instance": 'w'}
+        error_msg = get_error_msg(error_msg, f"Error writing JSON to '{params[0]}'")
+        
+        open_it = all_try(var_data=var_data, function=open, error_msg=error_msg)
+        
+        if open_it:
+            with open_it as file:
+                safe_dump_to_file(params[1], file, ensure_ascii=ensure_ascii, indent=indent)
+        
+            os.replace(temp_file_path, params[0])
+
+
 def safe_write_to_json(file_path:str=None, data:(dict or list or str)=None,*args, ensure_ascii=False, indent=4, error=False, error_msg=None, **kwargs):
     params = check_read_write_params(file_path=file_path,contents=data,*args, **kwargs)
     if params:
@@ -124,6 +141,25 @@ def safe_read_from_json(file_path):
     except Exception as e:
         logger.error(f"Error in safe_read_from_json: {e}\nFile path: {file_path}")
         return None
+def read_from_json(file_path):
+    return safe_read_from_json(file_path)
+def safe_load_from_json(file_path):
+    return safe_read_from_json(file_path)
+def safe_load_from_file(file_path):
+    return safe_read_from_json(file_path)
+def safe_json_reads(file_path):
+    return safe_read_from_json(file_path)
+
+
+def safe_dump_to_json(*args, **kwargs):
+    return safe_write_to_json(*args, **kwargs)
+def safe_write_to_json(*args, **kwargs):
+    return safe_write_to_json(*args, **kwargs)
+def safe_write_to_file(*args, **kwargs):
+    return safe_write_to_json(*args, **kwargs)
+
+
+
 def find_keys(data, target_keys):
     def _find_keys_recursive(data, target_keys, values):
         if isinstance(data, dict):
@@ -150,7 +186,30 @@ def try_json_load(file):
         return json.load(file)
     except json.JSONDecodeError:
         return None
-
+    
+def try_json_dump(file):
+    try:
+        return json.dump(file)
+    except json.JSONDecodeError:
+        return None
+    
+def try_json_dumps(data):
+    try:
+        return json.dumps(data)
+    except json.JSONDecodeError:
+        return None
+    
+def safe_json_loads(data):
+    return try_json_loads(data) or data
+    
+def safe_json_load(file):
+    return try_json_load(file) or file
+    
+def safe_json_dump(file):
+    return try_json_dump(file) or file
+    
+def safe_json_dumps(data):
+    return try_json_dumps(data) or data
 def unified_json_loader(file_path, default_value=None, encoding='utf-8'):
     # Try to load from the file
     with open(file_path, 'r', encoding=encoding) as file:
