@@ -356,7 +356,11 @@ def mkdirs(path: str) -> str:
     """
     os.makedirs(path, exist_ok=True)
     return path
-
+def make_dirs(*paths):
+    path = path_join(*paths)
+    if not os.path.isfile(path):
+        mkdirs(path)
+    return path
 def file_exists(file_path: str) -> bool:
     """
     Checks if a file exists at the specified path.
@@ -490,17 +494,17 @@ def is_last_itter(i,*itters):
         return True
     return False
 
-def path_join(*paths,isfile=False):
+def path_join(*paths, isfile=False):
     final_path = os.path.join(*paths)
     paths_len = len(paths)
-    for i,path in enumerate(paths):
+    for i, path in enumerate(paths):
         if i == 0:
-            final_path = paths
+            final_path = path  # Note: Fixed bug; original code had `final_path = paths`
         else:
-            final_path = os.path.join(final_path,path)
-        if isfile and is_last_itter(i,*itters):
+            final_path = os.path.join(final_path, path)
+        if isfile and is_last_itter(i, paths_len):  # Note: `is_last_itter` is undefined; assuming it checks if last iteration
             break
-        os.makedirs(final_path,exist_ok=True)      
+        os.makedirs(final_path, exist_ok=True)      
     return final_path
 
 def is_file(*paths):
@@ -520,7 +524,8 @@ def get_all_directories(directory):
     directory_list = [item for item in dir_list if is_dir(directory,item)]
     return directory_list
 
-def get_all_files(directory):
+def get_all_files(directory=None):
+    directory = directory or os.getcwd()
     dir_list = os.listdir(directory)
     file_list = [item for item in dir_list if is_file(directory,item)]
     return file_list
@@ -530,9 +535,8 @@ def get_all_items(directory):
     file_list = [item for item in dir_list if is_path(directory,item)]
     return file_list
 
-def collate_text_docs(directory):
-    directory_list = get_dirlist(directory)
-    return [get_content(directory,item) for item in directory_list if is_file(directory,item)]
+def collate_text_docs(directory=None):
+    return [read_from_file(item) for item in get_all_files(directory=directory)]
 
 def get_dirlist(directory):
     path = get_directory(directory)
