@@ -105,21 +105,36 @@ def break_down_find_existing(path):
     return test_path
 
 def string_in_keys(strings, kwargs):
-    return next((key for key in kwargs if any(s in key for s in strings)), None)
+    return next((key for key in kwargs if any(s.lower() in key.lower() for s in strings)), None)
 
 def get_path(paths):
     for path in paths:
         if isinstance(path,str):
-            if os.path.splitext(path)[1]:
-                return break_down_find_existing(path)
+            if os.path.isfile(path):
+                return path
+            dirname = os.path.dirname(path)
+            if os.path.exists(dirname):
+                return path
     return None
 
 def check_read_write_params(*args, **kwargs):
-    file_path_key = string_in_keys(['file','location','dir','directory','file_path', 'path'], kwargs)
-    file_path = kwargs.get(file_path_key) or get_path(args)
-    contents_key = string_in_keys(['contents', 'data','json_data', 'text', 'content', 'string'], kwargs)
-    contents = kwargs.get(contents_key) if contents_key else next((arg for arg in args if arg != file_path), None) 
-    return file_path,contents
+    file_path = kwargs.get('file_path', None)
+    contents = kwargs.get('contents', None)
+    if contents is None:
+        contents = kwargs.get('data', None)
+
+    # Handle positional arguments
+    if file_path is None and len(args) > 0:
+        file_path = args[0]
+    if contents is None and len(args) > 1:
+        contents = args[1]
+    elif contents is None and len(args) > 0 and file_path != args[0]:
+        contents = args[0]
+
+    if file_path is None or contents is None:
+        raise ValueError("Both 'file_path' and 'contents' (or 'data') are required.")
+
+    return file_path, contents
 
 def write_to_file(file_path=None, contents=None,*args,  **kwargs):
     """
@@ -163,15 +178,9 @@ def create_and_read_file(file_path=None, contents:str='',*args,  **kwargs) -> st
     Returns:
         The contents of the file.
     """
-    params = check_read_write_params(file_path=file_path,contents=contents,*args,  **kwargs)
-    if params:
-        file_path = params[0]
-        data = params[1]
-        if not os.path.isfile(file_path):
-            if error_msg == True:
-                error_msg = f"{file_path} does not exist; creating file with default_data"
-            write_to_file(file_path,contents)
-        return read_from_file(file_path)
+    if not os.path.isfile(file_path):
+        write_to_file(contents, file_path)
+    return read_from_file(file_path)
 def is_file_extension(obj: str) -> bool:
     """
     Check if a string has a file extension.
@@ -184,7 +193,7 @@ def is_file_extension(obj: str) -> bool:
     """
     return len(obj) >= 4 and '.' in obj[-4:-3]
 
-def delete_file(file_path:str):
+def delete_file(file_path: str):
     if os.path.isfile(file_path):
         os.remove(file_path)
 
