@@ -21,6 +21,7 @@ Author: putkoff
 Date: 05/31/2023
 Version: 0.1.2
 """
+import os
 def quoteIt(st: str, ls: list) -> str:
     """
     Quotes specific elements in a string.
@@ -173,3 +174,15 @@ def truncate_text(text, max_chars):
             truncated = truncated[:last_word_end]
     return truncated
 
+def url_join(*paths):
+    final_url = os.path.join(*paths)
+    for i,path in enumerate(paths):
+        if i == 0:
+            final_path = path  # Note: Fixed bug; original code had `final_path = paths`
+        else:
+            final_path = eatOuter(final_path, '/')
+            path = eatInner(path, '/')
+            final_path = f"{final_path}/{path}"
+    return final_path
+       
+    
