@@ -356,8 +356,26 @@ def get_creation_time_of_file(file_path):
         creation_time = os.path.getctime(file_path)
         return datetime.datetime.fromtimestamp(creation_time)
 
+def timestamp_to_milliseconds(timestamp):
+    try:
+        t = datetime.strptime(timestamp, "%H:%M:%S.%f")
+        return (t.hour * 3600 + t.minute * 60 + t.second) * 1000 + int(t.microsecond / 1000)
+    except ValueError:
+        raise ValueError(f"Invalid timestamp format: {timestamp}")
 
+def parse_timestamp(ts_str):
+    parts = ts_str.split(":")
+    return (int(parts[0]) * 60 + int(parts[1])) * 1000 if len(parts) == 2 else int(parts[0]) * 1000
+def format_timestamp(ms):
+    """Convert milliseconds to a formatted timestamp (HH:MM:SS.mmm)."""
+    td = timedelta(milliseconds=ms)
+    hours, remainder = divmod(td.seconds, 3600)
+    minutes, seconds = divmod(remainder, 60)
+    milliseconds = td.microseconds // 1000
+    return f"{hours:02d}:{minutes:02d}:{seconds:02d}.{milliseconds:03d}"
 
+def get_time_now_iso():
+    return datetime.now().isoformat()
 # Function: get_time_stamp
 # Function: get_milisecond_time_stamp
 # Function: get_day
