@@ -90,7 +90,16 @@ def confirm_type(file_path,media_types=None):
     for typ,exts in media_types.items():
          if ext in exts:
              return typ
-    
+def is_media_type(file_path,media_types=None):
+    media_types = make_list(media_types or [])
+    basename = os.path.basename(file_path)
+    filename,ext=os.path.splitext(basename)
+    media_types_js = get_media_types()
+    for media_type in media_types:
+        exts = media_types_js.get(media_type)
+        if exts and ext in exts:
+            return True
+    return False
 def get_all_types(types=None,directory=None):
     if not directory or not os.path.isdir(directory):
         return []
